pub struct ExtractedSierraProgram {
pub program: Program,
pub sierra_version: VersionId,
pub compiler_version: VersionId,
}Expand description
The Sierra program extracted from a contract class.
Fields
program: ProgramThe actual Sierra program.
sierra_version: VersionIdThe Sierra version used for the program.
compiler_version: VersionIdThe compiler version used for the program.
Implementations
Sourceimpl ExtractedSierraProgram
impl ExtractedSierraProgram
Sourcepub fn validate_version_compatible(
&self,
list_selector: ListSelector,
) -> Result<(), AllowedLibfuncsError>
pub fn validate_version_compatible( &self, list_selector: ListSelector, ) -> Result<(), AllowedLibfuncsError>
Checks that all the used libfuncs in the contract class are allowed in the contract class Sierra version.