NestedIntList

Enum NestedIntList 

pub enum NestedIntList {
    Leaf(usize),
    Node(Vec<NestedIntList>),
}
NestedIntList is either a list of NestedIntList or an integer. E.g., [0, [1, 2], [3, [4]]].

Used to represent the lengths of the segments in a contract, which are in the form of a tree.

For example, the contract may be segmented by functions, where each function is segmented by its branches. It is also possible to have the inner segmentation only for some of the functions, while others are kept as non-segmented leaves in the tree.

Variants